Class: OnyxCord::Components::MediaGallery

Inherits:
Object
  • Object
show all
Defined in:
lib/onyxcord/models/component.rb

Overview

A grouping of media attachments in an organized gallery format.

Defined Under Namespace

Classes: Item

Instance Attribute Summary collapse

Instance Attribute Details

#idInteger (readonly)

Returns the numeric identifier of the media gallery.

Returns:

  • (Integer)

    the numeric identifier of the media gallery.



325
326
327
# File 'lib/onyxcord/models/component.rb', line 325

def id
  @id
end

#itemsArray<Item> (readonly)

Returns the media items contained within the media gallery.

Returns:

  • (Array<Item>)

    the media items contained within the media gallery.



328
329
330
# File 'lib/onyxcord/models/component.rb', line 328

def items
  @items
end