Class: OnyxCord::Components::Separator

Inherits:
Object
  • Object
show all
Defined in:
lib/onyxcord/models/component.rb

Overview

A component that adds vertical padding and visual division.

Instance Attribute Summary collapse

Instance Attribute Details

#dividertrue, false (readonly) Also known as: divider?

Returns whether or not a visual divider should be displayed.

Returns:

  • (true, false)

    whether or not a visual divider should be displayed.



366
367
368
# File 'lib/onyxcord/models/component.rb', line 366

def divider
  @divider
end

#idInteger (readonly)

Returns the numeric identifier of the separator.

Returns:

  • (Integer)

    the numeric identifier of the separator.



363
364
365
# File 'lib/onyxcord/models/component.rb', line 363

def id
  @id
end

#spacingInteger (readonly)

Returns the size of the separator's padding. 1 for little padding, and 2 for big padding.

Returns:

  • (Integer)

    the size of the separator's padding. 1 for little padding, and 2 for big padding.



371
372
373
# File 'lib/onyxcord/models/component.rb', line 371

def spacing
  @spacing
end