Class: OnyxCord::Components::TextDisplay

Inherits:
Object
  • Object
show all
Defined in:
lib/onyxcord/models/component.rb

Overview

A content component representing message content.

Instance Attribute Summary collapse

Instance Attribute Details

#contentString (readonly)

Returns the content to be displayed for the text display.

Returns:

  • (String)

    the content to be displayed for the text display.



286
287
288
# File 'lib/onyxcord/models/component.rb', line 286

def content
  @content
end

#idInteger (readonly)

Returns the numeric identifier of the text display.

Returns:

  • (Integer)

    the numeric identifier of the text display.



283
284
285
# File 'lib/onyxcord/models/component.rb', line 283

def id
  @id
end