Exception: OnyxCord::Errors::MessageTooLong
- Inherits:
-
RuntimeError
- Object
- RuntimeError
- OnyxCord::Errors::MessageTooLong
- Defined in:
- lib/onyxcord/core/errors.rb
Overview
Raised when a message is over the character limit
Raised when a message is over the character limit