Class: OnyxCord::Events::ChannelPinsUpdateEvent

Inherits:
Event
  • Object
show all
Defined in:
lib/onyxcord/events/channels/pins.rb

Overview

Raised when a message is pinned or unpinned.

Instance Attribute Summary collapse

Attributes inherited from Event

#bot

Instance Attribute Details

#channelChannel (readonly)

Returns The channel this event originates from.

Returns:

  • (Channel)

    The channel this event originates from.



13
14
15
# File 'lib/onyxcord/events/channels/pins.rb', line 13

def channel
  @channel
end

#last_pin_timestampTime? (readonly)

Returns Time at which the most recent pinned message was pinned.

Returns:

  • (Time, nil)

    Time at which the most recent pinned message was pinned.



10
11
12
# File 'lib/onyxcord/events/channels/pins.rb', line 10

def last_pin_timestamp
  @last_pin_timestamp
end

#serverServer? (readonly)

Returns The server this event originates from.

Returns:

  • (Server, nil)

    The server this event originates from.



16
17
18
# File 'lib/onyxcord/events/channels/pins.rb', line 16

def server
  @server
end