Class: OnyxCord::Events::InviteCreateEvent

Inherits:
Event
  • Object
show all
Defined in:
lib/onyxcord/events/invite/create.rb

Overview

Raised when an invite is created.

Instance Attribute Summary collapse

Attributes inherited from Event

#bot

Instance Attribute Details

#channelChannel (readonly)

Returns The channel the invite was created for.

Returns:

  • (Channel)

    The channel the invite was created for.



15
16
17
# File 'lib/onyxcord/events/invite/create.rb', line 15

def channel
  @channel
end

#codeString (readonly)

Returns The code for the created invite.

Returns:

  • (String)

    The code for the created invite.

See Also:



35
# File 'lib/onyxcord/events/invite/create.rb', line 35

delegate :code, :created_at, :max_age, :max_uses, :temporary, :inviter, to: :invite

#created_atTime (readonly)

Returns The time the invite was created at.

Returns:

  • (Time)

    The time the invite was created at.

See Also:



35
# File 'lib/onyxcord/events/invite/create.rb', line 35

delegate :code, :created_at, :max_age, :max_uses, :temporary, :inviter, to: :invite

#inviteInvite (readonly)

Returns The invite that was created.

Returns:

  • (Invite)

    The invite that was created.



9
10
11
# File 'lib/onyxcord/events/invite/create.rb', line 9

def invite
  @invite
end

#inviterUser (readonly)

Returns The user that created the invite.

Returns:

  • (User)

    The user that created the invite.

See Also:



35
# File 'lib/onyxcord/events/invite/create.rb', line 35

delegate :code, :created_at, :max_age, :max_uses, :temporary, :inviter, to: :invite

#max_ageInteger (readonly)

Returns The maximum age of the created invite.

Returns:

  • (Integer)

    The maximum age of the created invite.

See Also:



35
# File 'lib/onyxcord/events/invite/create.rb', line 35

delegate :code, :created_at, :max_age, :max_uses, :temporary, :inviter, to: :invite

#max_usesInteger (readonly)

Returns The maximum number of uses before the invite expires.

Returns:

  • (Integer)

    The maximum number of uses before the invite expires.

See Also:



35
# File 'lib/onyxcord/events/invite/create.rb', line 35

delegate :code, :created_at, :max_age, :max_uses, :temporary, :inviter, to: :invite

#serverServer? (readonly)

Returns The server the invite was created for.

Returns:

  • (Server, nil)

    The server the invite was created for.



12
13
14
# File 'lib/onyxcord/events/invite/create.rb', line 12

def server
  @server
end

#temporarytrue, false (readonly) Also known as: temporary?

Returns Whether or not this invite grants temporary membership.

Returns:

  • (true, false)

    Whether or not this invite grants temporary membership.

See Also:



35
# File 'lib/onyxcord/events/invite/create.rb', line 35

delegate :code, :created_at, :max_age, :max_uses, :temporary, :inviter, to: :invite