Class: OnyxCord::Events::ServerDeleteEvent

Inherits:
ServerEvent show all
Defined in:
lib/onyxcord/events/guilds/base.rb

Overview

Server is deleted, the server was left because the bot was kicked, or the bot made itself leave the server.

Instance Attribute Summary collapse

Attributes inherited from Event

#bot

Instance Attribute Details

#serverInteger (readonly)

Returns The ID of the server that was left.

Returns:

  • (Integer)

    The ID of the server that was left.



82
83
84
# File 'lib/onyxcord/events/guilds/base.rb', line 82

def server
  @server
end