Class: OnyxCord::Events::ServerRoleDeleteEvent

Inherits:
Event
  • Object
show all
Defined in:
lib/onyxcord/events/role/delete.rb

Overview

Raised when a role is deleted from a server

Instance Attribute Summary collapse

Attributes inherited from Event

#bot

Instance Attribute Details

#idInteger (readonly)

Returns the ID of the role that got deleted.

Returns:

  • (Integer)

    the ID of the role that got deleted.



9
10
11
# File 'lib/onyxcord/events/role/delete.rb', line 9

def id
  @id
end

#serverServer (readonly)

Returns the server on which a role got deleted.

Returns:

  • (Server)

    the server on which a role got deleted.



12
13
14
# File 'lib/onyxcord/events/role/delete.rb', line 12

def server
  @server
end