Module: OnyxCord::Light
- Defined in:
- lib/onyxcord/light.rb,
lib/onyxcord/light/data.rb,
lib/onyxcord/light/light_bot.rb,
lib/onyxcord/light/integrations.rb
Overview
This module contains classes to allow connections to bots without a connection to the gateway socket, i.e. bots that only use the REST part of the API.
Defined Under Namespace
Classes: Connection, Integration, LightBot, LightProfile, LightServer, UltraLightServer