Module: OnyxCord::Voice

Defined in:
lib/onyxcord/voice/client.rb,
lib/onyxcord/voice/sodium.rb,
lib/onyxcord/voice/encoder.rb,
lib/onyxcord/voice/network.rb,
lib/onyxcord/voice/network/udp.rb,
lib/onyxcord/voice/network/websocket.rb

Overview

Discord voice chat support

Defined Under Namespace

Classes: Client, Encoder, VoiceUDP, VoiceWS, XChaCha20AEAD

Constant Summary collapse

IDEAL_LENGTH =

How long one voice packet should ideally be (20ms as defined by Discord)

20.0
DATA_LENGTH =

How many bytes of data to read (1920 bytes * 2 channels) from audio PCM data

1920 * 2
ENCRYPTED_MODE =
Deprecated.

Discord now supports multiple encryption options.

Signifies to Discord that encryption should be used TODO: Resolve replacement for this constant.

'aead_xchacha20_poly1305_rtpsize'
PLAIN_MODE =
Deprecated.

Discord no longer supports unencrypted voice communication.

Signifies to Discord that no encryption should be used

'plain'
ENCRYPTION_MODES =

Encryption modes supported by Discord

%w[aead_xchacha20_poly1305_rtpsize].freeze