Class: OnyxCord::Components::MediaGallery
- Inherits:
-
Object
- Object
- OnyxCord::Components::MediaGallery
- Defined in:
- lib/onyxcord/models/component.rb
Overview
A grouping of media attachments in an organized gallery format.
Defined Under Namespace
Classes: Item
Instance Attribute Summary collapse
-
#id ⇒ Integer
readonly
The numeric identifier of the media gallery.
-
#items ⇒ Array<Item>
readonly
The media items contained within the media gallery.
Instance Attribute Details
#id ⇒ Integer (readonly)
Returns the numeric identifier of the media gallery.
325 326 327 |
# File 'lib/onyxcord/models/component.rb', line 325 def id @id end |
#items ⇒ Array<Item> (readonly)
Returns the media items contained within the media gallery.
328 329 330 |
# File 'lib/onyxcord/models/component.rb', line 328 def items @items end |