Class: OnyxCord::Components::Separator
- Inherits:
-
Object
- Object
- OnyxCord::Components::Separator
- Defined in:
- lib/onyxcord/models/component.rb
Overview
A component that adds vertical padding and visual division.
Instance Attribute Summary collapse
-
#divider ⇒ true, false
(also: #divider?)
readonly
Whether or not a visual divider should be displayed.
-
#id ⇒ Integer
readonly
The numeric identifier of the separator.
-
#spacing ⇒ Integer
readonly
The size of the separator's padding.
Instance Attribute Details
#divider ⇒ true, false (readonly) Also known as: divider?
Returns whether or not a visual divider should be displayed.
366 367 368 |
# File 'lib/onyxcord/models/component.rb', line 366 def divider @divider end |
#id ⇒ Integer (readonly)
Returns the numeric identifier of the separator.
363 364 365 |
# File 'lib/onyxcord/models/component.rb', line 363 def id @id end |
#spacing ⇒ Integer (readonly)
Returns the size of the separator's padding. 1 for little padding,
and 2 for big padding.
371 372 373 |
# File 'lib/onyxcord/models/component.rb', line 371 def spacing @spacing end |