Class: OnyxCord::Components::TextDisplay
- Inherits:
-
Object
- Object
- OnyxCord::Components::TextDisplay
- Defined in:
- lib/onyxcord/models/component.rb
Overview
A content component representing message content.
Instance Attribute Summary collapse
-
#content ⇒ String
readonly
The content to be displayed for the text display.
-
#id ⇒ Integer
readonly
The numeric identifier of the text display.
Instance Attribute Details
#content ⇒ String (readonly)
Returns the content to be displayed for the text display.
286 287 288 |
# File 'lib/onyxcord/models/component.rb', line 286 def content @content end |
#id ⇒ Integer (readonly)
Returns the numeric identifier of the text display.
283 284 285 |
# File 'lib/onyxcord/models/component.rb', line 283 def id @id end |