Class: OnyxCord::Components::TextInput
- Inherits:
-
Object
- Object
- OnyxCord::Components::TextInput
- Defined in:
- lib/onyxcord/models/component.rb
Overview
A free-form text input bar in a modal.
Instance Attribute Summary collapse
-
#custom_id ⇒ String
readonly
The developer-defined identifier for the text input.
-
#id ⇒ Integer
readonly
The numeric identifier of the text input.
-
#style ⇒ Symbol
readonly
This is deprecated and not accurate.
-
#value ⇒ String?
readonly
The value the user typed into the text input.
Instance Attribute Details
#custom_id ⇒ String (readonly)
Returns the developer-defined identifier for the text input.
245 246 247 |
# File 'lib/onyxcord/models/component.rb', line 245 def custom_id @custom_id end |
#id ⇒ Integer (readonly)
Returns the numeric identifier of the text input.
235 236 237 |
# File 'lib/onyxcord/models/component.rb', line 235 def id @id end |
#style ⇒ Symbol (readonly)
Returns This is deprecated and not accurate. This will be removed in the next major version (4.0.0).
239 240 241 |
# File 'lib/onyxcord/models/component.rb', line 239 def style @style end |
#value ⇒ String? (readonly)
Returns the value the user typed into the text input.
242 243 244 |
# File 'lib/onyxcord/models/component.rb', line 242 def value @value end |