Class: OnyxCord::Events::ApplicationCommandPermissionsUpdateEvent
- Defined in:
- lib/onyxcord/events/interactions/permissions.rb
Overview
An event for whenever an application command's permissions are updated.
Instance Attribute Summary collapse
-
#application_id ⇒ Integer
readonly
The ID of the application whose commands were updated.
-
#command_id ⇒ Integer?
readonly
The ID of the application command that was updated.
-
#permissions ⇒ Array<ApplicationCommand::Permission>
readonly
The permissions that were updated.
-
#server_id ⇒ Integer
readonly
The ID of the server where the command permissions were updated.
Attributes inherited from Event
Instance Method Summary collapse
-
#server ⇒ Server
The server where the command's permissions were updated.
Instance Attribute Details
#application_id ⇒ Integer (readonly)
Returns the ID of the application whose commands were updated.
19 20 21 |
# File 'lib/onyxcord/events/interactions/permissions.rb', line 19 def application_id @application_id end |
#command_id ⇒ Integer? (readonly)
Returns the ID of the application command that was updated.
13 14 15 |
# File 'lib/onyxcord/events/interactions/permissions.rb', line 13 def command_id @command_id end |
#permissions ⇒ Array<ApplicationCommand::Permission> (readonly)
Returns the permissions that were updated.
16 17 18 |
# File 'lib/onyxcord/events/interactions/permissions.rb', line 16 def @permissions end |
#server_id ⇒ Integer (readonly)
Returns the ID of the server where the command permissions were updated.
10 11 12 |
# File 'lib/onyxcord/events/interactions/permissions.rb', line 10 def server_id @server_id end |
Instance Method Details
#server ⇒ Server
Returns the server where the command's permissions were updated.
33 34 35 |
# File 'lib/onyxcord/events/interactions/permissions.rb', line 33 def server @bot.server(@server_id) end |