Class: OnyxCord::Events::AuditLogEntryCreateEvent
- Defined in:
- lib/onyxcord/events/guilds/audit_logs.rb
Overview
Raised whenever an audit log entry is created.
Instance Attribute Summary collapse
-
#action ⇒ Integer
readonly
The raw action type of the audit log entry.
-
#entry ⇒ AuditLogs::Entry
readonly
The entry of the audit log event.
-
#server ⇒ Server
readonly
The server of the audit log event.
-
#target_id ⇒ Integer?
readonly
The ID of the affected webhook, user, etc.
-
#user_id ⇒ Integer
readonly
The ID of the user or bot that made the entry.
Attributes inherited from Event
Instance Attribute Details
#action ⇒ Integer (readonly)
Returns the raw action type of the audit log entry.
16 17 18 |
# File 'lib/onyxcord/events/guilds/audit_logs.rb', line 16 def action @action end |
#entry ⇒ AuditLogs::Entry (readonly)
Returns the entry of the audit log event.
13 14 15 |
# File 'lib/onyxcord/events/guilds/audit_logs.rb', line 13 def entry @entry end |
#server ⇒ Server (readonly)
Returns the server of the audit log event.
10 11 12 |
# File 'lib/onyxcord/events/guilds/audit_logs.rb', line 10 def server @server end |
#target_id ⇒ Integer? (readonly)
Returns the ID of the affected webhook, user, etc.
22 23 24 |
# File 'lib/onyxcord/events/guilds/audit_logs.rb', line 22 def target_id @target_id end |
#user_id ⇒ Integer (readonly)
Returns the ID of the user or bot that made the entry.
19 20 21 |
# File 'lib/onyxcord/events/guilds/audit_logs.rb', line 19 def user_id @user_id end |