Class: OnyxCord::Events::ChannelPinsUpdateEvent
- Defined in:
- lib/onyxcord/events/channels/pins.rb
Overview
Raised when a message is pinned or unpinned.
Instance Attribute Summary collapse
-
#channel ⇒ Channel
readonly
The channel this event originates from.
-
#last_pin_timestamp ⇒ Time?
readonly
Time at which the most recent pinned message was pinned.
-
#server ⇒ Server?
readonly
The server this event originates from.
Attributes inherited from Event
Instance Attribute Details
#channel ⇒ Channel (readonly)
Returns The channel this event originates from.
13 14 15 |
# File 'lib/onyxcord/events/channels/pins.rb', line 13 def channel @channel end |
#last_pin_timestamp ⇒ Time? (readonly)
Returns Time at which the most recent pinned message was pinned.
10 11 12 |
# File 'lib/onyxcord/events/channels/pins.rb', line 10 def @last_pin_timestamp end |
#server ⇒ Server? (readonly)
Returns The server this event originates from.
16 17 18 |
# File 'lib/onyxcord/events/channels/pins.rb', line 16 def server @server end |