Class: OnyxCord::Events::ServerRoleDeleteEvent
- Defined in:
- lib/onyxcord/events/role/delete.rb
Overview
Raised when a role is deleted from a server
Instance Attribute Summary collapse
-
#id ⇒ Integer
readonly
The ID of the role that got deleted.
-
#server ⇒ Server
readonly
The server on which a role got deleted.
Attributes inherited from Event
Instance Attribute Details
#id ⇒ Integer (readonly)
Returns the ID of the role that got deleted.
9 10 11 |
# File 'lib/onyxcord/events/role/delete.rb', line 9 def id @id end |
#server ⇒ Server (readonly)
Returns the server on which a role got deleted.
12 13 14 |
# File 'lib/onyxcord/events/role/delete.rb', line 12 def server @server end |